# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class GetSpotMarketPriceResult:
    """
    A collection of values returned by getSpotMarketPrice.
    """
    def __init__(__self__, price=None, id=None):
        if price and not isinstance(price, float):
            raise TypeError('Expected argument price to be a float')
        __self__.price = price
        """
        Current spot market price for given plan in given facility.
        """
        if id and not isinstance(id, str):
            raise TypeError('Expected argument id to be a str')
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """

async def get_spot_market_price(facility=None,plan=None,opts=None):
    """
    Use this data source to get Packet Spot Market Price.
    """
    __args__ = dict()

    __args__['facility'] = facility
    __args__['plan'] = plan
    __ret__ = await pulumi.runtime.invoke('packet:index/getSpotMarketPrice:getSpotMarketPrice', __args__, opts=opts)

    return GetSpotMarketPriceResult(
        price=__ret__.get('price'),
        id=__ret__.get('id'))
