# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "access_private_ipv4": "accessPrivateIpv4",
    "access_public_ipv4": "accessPublicIpv4",
    "access_public_ipv6": "accessPublicIpv6",
    "address_family": "addressFamily",
    "always_pxe": "alwaysPxe",
    "auth_token": "authToken",
    "bgp_config": "bgpConfig",
    "billing_cycle": "billingCycle",
    "cidr_notation": "cidrNotation",
    "device_id": "deviceId",
    "devices_max": "devicesMax",
    "devices_min": "devicesMin",
    "global_": "global",
    "hardware_reservation_id": "hardwareReservationId",
    "instance_parameters": "instanceParameters",
    "ipxe_script_url": "ipxeScriptUrl",
    "max_bid_price": "maxBidPrice",
    "operating_system": "operatingSystem",
    "organization_id": "organizationId",
    "payment_method_id": "paymentMethodId",
    "project_id": "projectId",
    "project_ssh_key_ids": "projectSshKeyIds",
    "public_ipv4_subnet_size": "publicIpv4SubnetSize",
    "public_key": "publicKey",
    "root_password": "rootPassword",
    "snapshot_policies": "snapshotPolicies",
    "ssh_key_ids": "sshKeyIds",
    "user_data": "userData",
    "volume_id": "volumeId",
    "wait_for_devices": "waitForDevices",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "accessPrivateIpv4": "access_private_ipv4",
    "accessPublicIpv4": "access_public_ipv4",
    "accessPublicIpv6": "access_public_ipv6",
    "addressFamily": "address_family",
    "alwaysPxe": "always_pxe",
    "authToken": "auth_token",
    "bgpConfig": "bgp_config",
    "billingCycle": "billing_cycle",
    "cidrNotation": "cidr_notation",
    "deviceId": "device_id",
    "devicesMax": "devices_max",
    "devicesMin": "devices_min",
    "global": "global_",
    "hardwareReservationId": "hardware_reservation_id",
    "instanceParameters": "instance_parameters",
    "ipxeScriptUrl": "ipxe_script_url",
    "maxBidPrice": "max_bid_price",
    "operatingSystem": "operating_system",
    "organizationId": "organization_id",
    "paymentMethodId": "payment_method_id",
    "projectId": "project_id",
    "projectSshKeyIds": "project_ssh_key_ids",
    "publicIpv4SubnetSize": "public_ipv4_subnet_size",
    "publicKey": "public_key",
    "rootPassword": "root_password",
    "snapshotPolicies": "snapshot_policies",
    "sshKeyIds": "ssh_key_ids",
    "userData": "user_data",
    "volumeId": "volume_id",
    "waitForDevices": "wait_for_devices",
}
