# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from .. import utilities, tables

__config__ = pulumi.Config('packet')

auth_token = utilities.require_with_default(lambda: __config__.require('authToken'), utilities.get_env('PACKET_AUTH_TOKEN'))
"""
The API auth key for API operations.
"""

